@@ -17,8 +17,8 @@ __package_name__ = 'Flask-Hypertable'
 __author__ = 'Fairiz Azizi'
 __description__ = 'A Flask extension for Hypertable over Thrift.'
 __email__ = 'coderfi@gmail.com'
-__version__ = '0.1.3'
+__version__ = '0.3.0'
 __license__ = 'BSD'
 __copyright__ = 'Copyright 2014 Fairiz Azizi'
 
-from .flask_hypertable import FlaskHypertable
+from .flask_hypertable import FlaskHypertable, FlaskPooledHypertable
